# -*- coding: utf-8 -*-
"""
TNSCM by LimberDuck (pronounced *ˈlɪm.bɚ dʌk*) is a CLI tool which
enables you to perform certain actions on Tenable Nessus by (C) Tenable,
Inc. via Nessus API.
Copyright (C) 2025 Damian Krawczyk

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

__all__ = [
    "__title__",
    "__icon__",
    "__summary__",
    "__uri__",
    "__version__",
    "__release_date__",
    "__author__",
    "__email__",
    "__license_name__",
    "__license_link__",
    "__copyright__",
]

__title__ = "TNSCM by LimberDuck"
__package_name__ = "tnscm"
__icon__ = "LimberDuck-tnscm.ico"
__summary__ = (
    "TNSCM by LimberDuck (pronounced *ˈlɪm.bɚ dʌk*) is a CLI tool which"
    "enables you to perform certain actions on Tenable Nessus by (C) Tenable,"
    "Inc. via Nessus API."
)
__uri__ = "https://github.com/LimberDuck"
__version__ = "0.0.6"
__release_date__ = "2025.09.01"
__author__ = "Damian Krawczyk"
__email__ = "damian.krawczyk@limberduck.org"
__license_name__ = "GNU GPLv3"
__license_link__ = "https://www.gnu.org/licenses/gpl-3.0.en.html"
__copyright__ = "\N{COPYRIGHT SIGN} 2021-2025 by %s" % __author__
